/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM mozIXMLTermStream.idl
 */

#ifndef __gen_mozIXMLTermStream_h__
#define __gen_mozIXMLTermStream_h__


#ifndef __gen_nsIInputStream_h__
#include "nsIInputStream.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindowInternal; /* forward declaration */

#define MOZXMLTERMSTREAM_CLASSNAME  "XMLTermStream Component"
#define MOZXMLTERMSTREAM_CONTRACTID "@mozilla.org/xmlterm/xmlterm-stream;1"
#define MOZXMLTERMSTREAM_CID                 \
{ /* 0eb82b41-43a2-11d3-8e76-006008948af5 */ \
   0x0eb82b41, 0x43a2, 0x11d3,               \
{0x8e, 0x76, 0x00, 0x60, 0x08, 0x94, 0x8a, 0xf5} }

/* starting interface:    mozIXMLTermStream */
#define MOZIXMLTERMSTREAM_IID_STR "0eb82b40-43a2-11d3-8e76-006008948af5"

#define MOZIXMLTERMSTREAM_IID \
  {0x0eb82b40, 0x43a2, 0x11d3, \
    { 0x8e, 0x76, 0x00, 0x60, 0x08, 0x94, 0x8a, 0xf5 }}

class NS_NO_VTABLE mozIXMLTermStream : public nsIInputStream {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(MOZIXMLTERMSTREAM_IID)

  /** Open stream in specified frame, or in current frame if frameName is null
   * @param aDOMWindow parent window
   * @param frameName name of child frame in which to display stream, or null
   *                  to display in parent window
   * @param contentURL URL of stream content
   * @param contentType MIME type of stream content
   * @param maxResizeHeight maximum resize height (0=> do not resize)
   */
  /* void open (in nsIDOMWindowInternal aDOMWindow, in string frameName, in string contentURL, in string contentType, in long maxResizeHeight); */
  NS_IMETHOD Open(nsIDOMWindowInternal *aDOMWindow, const char *frameName, const char *contentURL, const char *contentType, PRInt32 maxResizeHeight) = 0;

  /** Write Unicode string to stream (blocks until write is completed)
   * @param buf string to write
   */
  /* void write (in wstring buf); */
  NS_IMETHOD Write(const PRUnichar *buf) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_MOZIXMLTERMSTREAM \
  NS_IMETHOD Open(nsIDOMWindowInternal *aDOMWindow, const char *frameName, const char *contentURL, const char *contentType, PRInt32 maxResizeHeight); \
  NS_IMETHOD Write(const PRUnichar *buf); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_MOZIXMLTERMSTREAM(_to) \
  NS_IMETHOD Open(nsIDOMWindowInternal *aDOMWindow, const char *frameName, const char *contentURL, const char *contentType, PRInt32 maxResizeHeight) { return _to Open(aDOMWindow, frameName, contentURL, contentType, maxResizeHeight); } \
  NS_IMETHOD Write(const PRUnichar *buf) { return _to Write(buf); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_MOZIXMLTERMSTREAM(_to) \
  NS_IMETHOD Open(nsIDOMWindowInternal *aDOMWindow, const char *frameName, const char *contentURL, const char *contentType, PRInt32 maxResizeHeight) { return !_to ? NS_ERROR_NULL_POINTER : _to->Open(aDOMWindow, frameName, contentURL, contentType, maxResizeHeight); } \
  NS_IMETHOD Write(const PRUnichar *buf) { return !_to ? NS_ERROR_NULL_POINTER : _to->Write(buf); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public mozIXMLTermStream
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_MOZIXMLTERMSTREAM

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, mozIXMLTermStream)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void open (in nsIDOMWindowInternal aDOMWindow, in string frameName, in string contentURL, in string contentType, in long maxResizeHeight); */
NS_IMETHODIMP _MYCLASS_::Open(nsIDOMWindowInternal *aDOMWindow, const char *frameName, const char *contentURL, const char *contentType, PRInt32 maxResizeHeight)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void write (in wstring buf); */
NS_IMETHODIMP _MYCLASS_::Write(const PRUnichar *buf)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_mozIXMLTermStream_h__ */
